@@ -3,6 +3,8 @@ import sys
 import argparse
 from datetime import datetime
 
+OUTPUT_PATH = "~/.now.txt"
+
 
 def make_parser():
     parser = argparse.ArgumentParser()
@@ -11,7 +13,7 @@ def make_parser():
 
 
 def get_output_file():
-    path = os.path.expanduser("~/doings.txt")
+    path = os.path.expanduser(OUTPUT_PATH)
     output = open(path, 'a+b')
     return output
 
